@@ -24,7 +24,19 @@ import socket
 from kegbot.api import kbapi
 from . import common_defs
 
+class BackendException(Exception):
+  """Base exception type."""
+
+
+class DoesNotExistException(BackendException):
+  """Thrown when operating against a non-existing resource."""
+
+
 class Backend(object):
+
+  def GetStatus(self):
+    raise NotImplementedError
+
   def GetAllTaps(self):
     raise NotImplementedError
 
@@ -46,18 +58,29 @@ class WebBackend(Backend):
     self._logger = logging.getLogger('api-backend')
     self._client = kbapi.Client(api_url=api_url, api_key=api_key)
 
-  def GetAllTaps(self):
-    return self._client.TapStatus()
+  def GetStatus(self):
+    return self._client.status()
 
-  def RecordDrink(self, tap_name, ticks, volume_ml=None, username=None,
+  def GetAllTaps(self):
+    return self._client.taps()
+
+  def RecordDrink(self, meter_name, ticks, volume_ml=None, username=None,
       pour_time=None, duration=0, auth_token=None, spilled=False, shout=''):
-    return self._client.RecordDrink(tap_name=tap_name, ticks=ticks,
-        volume_ml=volume_ml, username=username, pour_time=pour_time,
-        duration=duration, auth_token=auth_token, spilled=spilled,
-        shout=shout)
+    try:
+      return self._client.record_drink(tap_name=meter_name, ticks=ticks,
+          volume_ml=volume_ml, username=username, pour_time=pour_time,
+          duration=duration, auth_token=auth_token, spilled=spilled,
+          shout=shout)
+    except kbapi.NotFoundError as e:
+      raise DoesNotExistException('Cannot record against meter "%s": %s' % (meter_name, e))
+    except kbapi.Error as e:
+      raise BackendException(e)
 
   def CancelDrink(self, seqn, spilled=False):
-    return self._client.CancelDrink(seqn, spilled)
+    try:
+      return self._client.cancel_drink(seqn, spilled)
+    except kbapi.Error as e:
+      raise BackendException(e)
 
   def LogSensorReading(self, sensor_name, temperature, when=None):
     # If the temperature is out of bounds, reject it.
@@ -67,7 +90,7 @@ class WebBackend(Backend):
       raise ValueError, 'Temperature out of bounds'
 
     try:
-      return self._client.LogSensorReading(sensor_name, temperature, when)
+      return self._client.log_sensor_reading(sensor_name, temperature, when)
     except kbapi.NotFoundError:
       self._logger.warning('No sensor on backend named "%s"' % (sensor_name,))
       return None
@@ -80,7 +103,7 @@ class WebBackend(Backend):
 
   def GetAuthToken(self, auth_device, token_value):
     try:
-      return self._client.GetToken(auth_device, token_value)
+      return self._client.get_token(auth_device, token_value)
     except kbapi.NotFoundError:
       raise
     except socket.error:
